"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AwaitControl_1 = require("./AwaitControl");
class AsyncActionControl {
    constructor(label, rawKey, stateActions) {
        this.label = label;
        this.rawKey = rawKey;
        this.start = stateActions.start;
        this.success = stateActions.success;
        this.failure = stateActions.failure;
        this.cancel = stateActions.cancel;
        this.clear = stateActions.clear;
    }
    getKey(actionId) {
        if (actionId) {
            return `${this.rawKey}_${actionId.toString().toUpperCase()}`;
        }
        return this.rawKey;
    }
    getData(s, actionId) {
        const stored = s[AwaitControl_1.default.getControl().keyReducer][this.getKey(actionId)];
        if (stored) {
            const [state, resultData] = stored;
            return { state, resultData };
        }
        return {};
    }
    getStateValue(state, actionId) {
        return this.getData(state, actionId).state;
    }
    getResultValue(state, actionId) {
        return this.getData(state, actionId).resultData;
    }
    isRunning(actionId) {
        return (state) => this.getStateValue(state, actionId) === 'START';
    }
    isCancelled(actionId) {
        return (state) => this.getStateValue(state, actionId) === 'CANCEL';
    }
    hasFailure(actionId) {
        return (state) => this.getStateValue(state, actionId) === 'FAILURE';
    }
    isSuccessful(actionId) {
        return (state) => this.getStateValue(state, actionId) === 'SUCCESS';
    }
    getResult(actionId) {
        return (state) => this.getResultValue(state, actionId);
    }
}
exports.default = AsyncActionControl;
